@@ -204,7 +204,9 @@ class HttpClient(AllRouteHttpRequests, AuthHttpRequests, ClientMixin, Singleton)
                 await asyncio.sleep(2 + attempt * 3)
                 continue
 
-        self._client.logger.exception(f"{route_with_params}- Aborting. Failed {self._max_attempts} times")
+        self._client.logger.exception(
+            f"{route_with_params}- Aborting. Failed {self._max_attempts} times. Infos: {method=} | {auth=} | {data=} | {form_data=}"
+        )
         raise TimeoutException
 
     async def _handle_response(self, route_with_params: str, response: ClientResponse, content: dict) -> bool:
@@ -228,21 +230,35 @@ class HttpClient(AllRouteHttpRequests, AuthHttpRequests, ClientMixin, Singleton)
         Returns:
             If the response was OK
         """
+
         # get the bungie errors from the json
         if (error := content.get("error", None)) is None:
             error = content.get("ErrorStatus", "MISSING")
+            error_message = content.get("Message", "MISSING")
+        else:
+            # auth routes have different error code locations which are undocumented
+            error_message = content.get("error_description", "MISSING")
+            if error == "server_error":
+                error = content.get("error_description", error)
+
         error_code = content.get("ErrorCode", -1)
-        error_message = content.get("Message", "MISSING")
         error_data = content.get("MessageData", {})
 
         match (response.status, error):
             case (_, "SystemDisabled"):
                 raise BungieDead
 
+            case (_, "invalid_grant"):
+                # unauthorized
+                self._client.logger.warning(
+                    f"`{response.status} - {error} | {error_code}`: Unauthorized (too slow, user fault) request for `{route_with_params}`\n{content=}"
+                )
+                raise AuthenticationTooSlow
+
             case (200, _):
                 # make sure we got a json
                 if not content:
-                    self._client.logger.debug(f"Wrong content type returned text: '{await response.text()}'")
+                    self._client.logger.warning(f"Wrong content type returned text: '{await response.text()}'")
                     await asyncio.sleep(3)
                     return False
                 return True
@@ -256,31 +272,24 @@ class HttpClient(AllRouteHttpRequests, AuthHttpRequests, ClientMixin, Singleton)
                 )
                 raise _RouteError(route=new_route)
 
-            case (401, _) | (_, "invalid_grant"):
-                # unauthorized
-                self._client.logger.debug(
-                    f"`{response.status} - {error} | {error_code}`: Unauthorized (too slow, user fault) request for `{route_with_params}`"
-                )
-                raise AuthenticationTooSlow
-
             case (502, _):
                 # bad gateway
-                self._client.logger.debug(
+                self._client.logger.warning(
                     f"Retrying... - `{response.status}` Bad gateway error for `{route_with_params}`"
                 )
                 await asyncio.sleep(5)
 
             case (524, _):
                 # cloudflare error, retry
-                self._client.logger.debug(
+                self._client.logger.warning(
                     f"Retrying... - `{response.status}` Cloudflare error for `{route_with_params}`"
                 )
                 await asyncio.sleep(2)
 
             case (429, _) | (_, "PerEndpointRequestThrottleExceeded" | "DestinyDirectBabelClientTimeout"):
                 # we are getting throttled (should never be called in theory)
-                self._client.logger.debug(
-                    f"`{response.status} - {error} | {error_code}`: Retrying... - Getting throttled for `{route_with_params}`\n{content}"
+                self._client.logger.warning(
+                    f"`{response.status} - {error} | {error_code}`: Retrying... - Getting throttled for `{route_with_params}`\n{content=}"
                 )
 
                 throttle_seconds = content["ThrottleSeconds"]
@@ -291,32 +300,29 @@ class HttpClient(AllRouteHttpRequests, AuthHttpRequests, ClientMixin, Singleton)
 
             case (_, "DestinyDirectBabelClientTimeout"):
                 # timeout
-                self._client.logger.debug(
-                    f"`{response.status} - {error} | {error_code}`: Retrying... - Getting timeouts for `{route_with_params}`\n{content}"
+                self._client.logger.warning(
+                    f"`{response.status} - {error} | {error_code}`: Retrying... - Getting timeouts for `{route_with_params}`\n{content=}"
                 )
                 await asyncio.sleep(60)
 
-            case (_, "server_error" | "DestinyServiceFailure" | "DestinyInternalError" | "UnhandledException"):
+            case (_, "DestinyServiceFailure" | "DestinyInternalError" | "UnhandledException"):
                 # timeout
-                self._client.logger.debug(
-                    f"`{response.status} - {error} | {error_code}`: Retrying... - Bungie is having problems `{route_with_params}`\n{content}"
+                self._client.logger.warning(
+                    f"`{response.status} - {error} | {error_code}`: Retrying... - Bungie is having problems `{route_with_params}`\n{content=}"
                 )
                 await asyncio.sleep(60)
 
             case (
                 _,
-                "AuthorizationRecordRevoked"
-                | "AuthorizationRecordExpired"
-                | "WebAuthRequired"
-                | "AuthorizationCodeInvalid",
+                "AuthorizationRecordRevoked" | "AuthorizationRecordExpired",
             ):
                 # users tokens are no longer valid
                 raise _InvalidAuthentication()
 
             case (404, _):
                 # not found
-                self._client.logger.debug(
-                    f"`{response.status} - {error} | {error_code}`: Not found for `{route_with_params}`\n{content}"
+                self._client.logger.warning(
+                    f"`{response.status} - {error} | {error_code}`: Not found for `{route_with_params}`\n{content=}"
                 )
 
                 if error != "MISSING":
@@ -324,10 +330,10 @@ class HttpClient(AllRouteHttpRequests, AuthHttpRequests, ClientMixin, Singleton)
                 else:
                     raise NotFound
 
-            case (400, _):
+            case ((400 | 401), _):
                 # generic bad request, such as wrong format
-                self._client.logger.debug(
-                    f"`{response.status} - {error} | {error_code}`: Generic bad request for `{route_with_params}`\n{content}"
+                self._client.logger.warning(
+                    f"`{response.status} - {error} | {error_code}`: Generic bad request for `{route_with_params}`\n{content=}"
                 )
 
                 if error != "MISSING":
@@ -336,8 +342,8 @@ class HttpClient(AllRouteHttpRequests, AuthHttpRequests, ClientMixin, Singleton)
                     raise BadRequest
 
             case (503, _):
-                self._client.logger.debug(
-                    f"`{response.status} - {error} | {error_code}`: Retrying... - Server is overloaded for `{route_with_params}`\n{content}"
+                self._client.logger.warning(
+                    f"`{response.status} - {error} | {error_code}`: Retrying... - Server is overloaded for `{route_with_params}`\n{content=}"
                 )
                 await asyncio.sleep(10)
 
@@ -346,7 +352,7 @@ class HttpClient(AllRouteHttpRequests, AuthHttpRequests, ClientMixin, Singleton)
                 retry = error == "Success"
 
                 # catch the rest
-                self._client.logger.debug(
+                self._client.logger.warning(
                     f"`{status} - {error} | {error_code}` - Request failed for `{route_with_params}` - `{error_message}`"
                 )
 
