@@ -1,13 +1,12 @@
 from datetime import datetime
 from typing import TYPE_CHECKING, AsyncGenerator, Optional, Union
 
-import attr
-
-from bungio.models.base import ClientMixin, FuzzyAttrFinder
+from bungio.models.base import ClientMixin, FuzzyAttrFinder, custom_define
 
 if TYPE_CHECKING:
     # AUTOMATIC IMPORTS START
     from bungio.models import (
+        BungieMembershipType,
         BungieRewardDisplay,
         DestinyComponentType,
         DestinyHistoricalStatsAccountResult,
@@ -35,11 +34,23 @@ if TYPE_CHECKING:
     from bungio.models.bungie import DestinyActivityModeType
     from bungio.models.overwrites import DestinyHistoricalStatsPeriodGroup
 
+
 __all__ = ("DestinyUserMixin",)
 
 
-@attr.define
+@custom_define()
 class DestinyUserMixin(ClientMixin, FuzzyAttrFinder):
+    @property
+    def full_bungie_name(self) -> str:
+        """
+        Return the formatted bungie name like it is seen in-game. This includes the four numbers
+
+        Returns:
+            The full bungie name
+        """
+
+        return f"""{self.bungie_global_display_name}#{str(self.bungie_global_display_name_code).zfill(4)}"""
+
     async def yield_activity_history(
         self,
         mode: Union["DestinyActivityModeType", int],
@@ -59,17 +70,29 @@ class DestinyUserMixin(ClientMixin, FuzzyAttrFinder):
         Returns:
             A generator for the model which is returned by bungie. [General endpoint information.](https://bungie-net.github.io/multi/index.html)
         """
+        from bungio.models.basic import DestinyCharacter
 
         # get character ids and gen functions
-        characters = await self.get_profile(components=[200], auth=auth)
+        # use the stats page to also get deleted chars
+        data = await self.get_historical_stats_for_account(groups=[0], auth=auth)
+
+        characters = [
+            DestinyCharacter(
+                membership_id=self._fuzzy_getattr("membership_id"),
+                membership_type=self._fuzzy_getattr("membership_type"),
+                character_id=character.character_id,
+            )
+            for character in data.characters
+        ]
+
         funcs = {
             i: character.yield_activity_history(
                 mode=mode,
                 earliest_allowed_datetime=earliest_allowed_datetime,
                 latest_allowed_datetime=latest_allowed_datetime,
                 auth=auth,
-            )  # noqa
-            for i, character in enumerate(characters.characters.data.values())
+            )
+            for i, character in enumerate(characters)
         }
 
         # gen the first values
